These *small* datasets are meant to aid in some of the nuctools functions, e.g., 
to compute atomic number densities in `scaledata_tools.py` and convert element
names to number of protons in `chem_tools.py`.

- `mm-dict.json` : dictionary mapping molar masses to element symbols
- `protons.json` : dictionary mapping atomic charge (Z) to element symbols
- `unary-list.json` : dictionary of some unary salt compounds, their stoiciometry, and molar masses


